..
   This is an autogenerated file from processors.rst

avatars.processors.InterRecordBoundedRangeDifferenceProcessor
=============================================================

.. autoclass:: avatars.processors.InterRecordBoundedRangeDifferenceProcessor
   :members: